export interface SystemTrackData extends Serializable {
    trackID: number;
    combinedList: Combination[];
    kinematic: Kinematics;
    characteristic: Characteristics;
    sourceList: SourceTrackDataKey[];
}
export interface SourceTrackData extends Serializable {
    sourceData: SourceData;
    kinematic: Kinematics;
    characteristic: Characteristics;
}
export interface Combination extends Serializable {
    trackID: number;
    combinationType: CombinationType;
}
export interface Kinematics extends Serializable {
    discriminator: KinematicsType;
    bearingKinematic: BearingKinematics;
    pointKinematic: PointKinematics;
}
export interface Characteristics extends Serializable {
    trackNumbers: TrackNumbers;
    trackName: string;
    classification: Classification;
    status: TrackStatus;
    trackTypeParams: TrackTypeParams;
    operatorOverwrited: boolean;
}
export interface SourceTrackDataKey extends Serializable {
    sourceID: number;
    sourceName: string;
    sourceTrackNumber: number;
    sourceType: SourceType;
}
export interface Serializable {
}
export interface SourceData extends Serializable {
    sourceID: number;
    sourceName: string;
    sourceTrackNumber: number;
    sourceType: SourceType;
    sourceTypeData: SourceTypeData;
}
export interface CombinationType extends Serializable {
    value: number;
}
export interface KinematicsType extends Serializable {
    value: number;
}
export interface BearingKinematics extends Serializable {
    origin: GeoLocation3d;
    velocity: Velocity;
    velocityValidity: boolean;
    updateTime: Time;
    observationTime: Time;
    distance: number;
    distanceValidity: boolean;
    bearing: Bearing;
    bearingValidity: boolean;
    elevation: number;
    elevationValidity: boolean;
    trackQuality: number;
    cpa: CPA;
    cpaValidity: boolean;
}
export interface PointKinematics extends Serializable {
    position: GeoLocation3d;
    positionValidity: boolean;
    velocity: Velocity;
    velocityValidity: boolean;
    updateTime: Time;
    observationTime: Time;
    distance: number;
    distanceValidity: boolean;
    bearing: Bearing;
    bearingValidity: boolean;
    elevation: number;
    elevationValidity: boolean;
    trackQuality: number;
    datumKinematicValidity: boolean;
    datumKinematic: DatumKinematic;
    cpa: CPA;
    cpaValidity: boolean;
    positionAccuracy: PositionAccuracy;
    positionAccuracyValidy: boolean;
}
export interface TrackNumbers extends Serializable {
    sourceTN: number;
    localDisplayTN: string;
    systemTN: number;
    linkTN: number;
    displayTNSelector: DisplayTNSelector;
}
export interface Classification extends Serializable {
    category: Category;
    identity: Identity;
    submarineConfidenceLevel: SubmarineConfidenceLevel;
    platform: number;
}
export interface TrackStatus extends Serializable {
    trackLife: TrackLife;
    combinationMethod: CombinationMethod;
    engagement: Engagement;
}
export interface TrackTypeParams extends Serializable {
    discriminator: TrackType;
    pointTrack: PointTrackParams;
    bearingTrack: BearingTrackParams;
    referencePoint: ReferencePointParams;
    emergencyPoint: EmergencyPointParams;
    landPoint: LandPointParams;
    ewBearing: EWBearingParams;
    wais: WAISParams;
}
export interface SourceType extends Serializable {
    value: number;
}
export interface SourceTypeData extends Serializable {
    discriminator: SourceType;
    waisData: WAISData;
}
export interface GeoLocation3d extends Serializable {
    latitude: number;
    longitude: number;
    altitude: number;
}
export interface Velocity extends Serializable {
    course: Course;
    speed: number;
}
export interface Time extends Serializable {
    utc: number;
}
export interface Bearing extends Serializable {
    trueBearing: number;
    relativeBearing: number;
}
export interface CPA extends Serializable {
    timeToCPA: number;
    distanceToCPA: number;
}
export interface DatumKinematic extends Serializable {
    tda: number;
    foc: number;
}
export interface PositionAccuracy extends Serializable {
    circleSquareType: CircleSquareType;
    axisOrientation: number;
    majorAxis: number;
    minorAxis: number;
}
export interface DisplayTNSelector extends Serializable {
    value: number;
}
export interface Category extends Serializable {
    value: number;
}
export interface Identity extends Serializable {
    value: number;
}
export interface SubmarineConfidenceLevel extends Serializable {
    value: number;
}
export interface TrackLife extends Serializable {
    value: number;
}
export interface CombinationMethod extends Serializable {
    value: number;
}
export interface Engagement extends Serializable {
    operatorOverwrited: boolean;
    isHoldFire: boolean;
    isEngageable: boolean;
}
export interface TrackType extends Serializable {
    value: number;
}
export interface PointTrackParams extends Serializable {
    dataReportType: DataReportType;
}
export interface BearingTrackParams extends Serializable {
    dataReportType: DataReportType;
}
export interface ReferencePointParams extends Serializable {
    referenceType: number;
    altitude: number;
}
export interface EmergencyPointParams extends Serializable {
    emergencyType: number;
    personnelInvolved: number;
    epPositionAccuracy: number;
}
export interface LandPointParams extends Serializable {
    landSpecificType: number;
    landPlatformActivity: number;
}
export interface EWBearingParams extends Serializable {
    bearingDescriptor: EWBearingDescriptor;
    emitterNumberValidity: boolean;
    emitterNumber: number;
    emitterFunction: number;
    prf: number;
    pri: number;
    pulseWidth: number;
    scanPeriod: number;
    scanRate: number;
    polarization: PolarizationType;
    lockOnStatus: LockOnStatus;
}
export interface WAISParams extends Serializable {
    name: string;
    imo: string;
    mmsi: string;
    callSign: string;
    flag: string;
    type: string;
}
export interface WAISData extends Serializable {
    name: string;
    imo: string;
    mmsi: string;
    callSign: string;
    flag: string;
    type: string;
}
export interface Course extends Serializable {
    trueCourse: number;
    relativeCourse: number;
}
export interface CircleSquareType extends Serializable {
    value: number;
}
export interface DataReportType extends Serializable {
    value: number;
}
export interface EWBearingDescriptor extends Serializable {
    value: number;
}
export interface PolarizationType extends Serializable {
    value: number;
}
export interface LockOnStatus extends Serializable {
    value: number;
}
